@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 1992-2006 Trolltech ASA. All rights reserved.
 **
 ** This file is part of the QtNetwork module of the Qt Toolkit.
 **
@@ -27,6 +27,8 @@
 #include <QtCore/qstring.h>
 #include <QtNetwork/qabstractsocket.h>
 
+QT_BEGIN_HEADER
+
 QT_MODULE(Network)
 
 struct sockaddr;
@@ -84,6 +86,10 @@ public:
 
     bool operator ==(const QHostAddress &address) const;
     bool operator ==(SpecialAddress address) const;
+    inline bool operator !=(const QHostAddress &address) const
+    { return !operator==(address); }
+    inline bool operator !=(SpecialAddress address) const
+    { return !operator==(address); }
     bool isNull() const;
     void clear();
 
@@ -107,4 +113,13 @@ inline bool operator ==(QHostAddress::SpecialAddress address1, const QHostAddres
 Q_NETWORK_EXPORT QDebug operator<<(QDebug, const QHostAddress &);
 #endif
 
+
+Q_NETWORK_EXPORT uint qHash(const QHostAddress &key);
+
+#ifndef QT_NO_DATASTREAM
+Q_NETWORK_EXPORT QDataStream &operator<<(QDataStream &, const QHostAddress &);
+Q_NETWORK_EXPORT QDataStream &operator>>(QDataStream &, QHostAddress &);
+#endif
+
+QT_END_HEADER
 #endif // QHOSTADDRESS_H
