@@ -5,15 +5,17 @@
 #  define QT_EDITION QT_EDITION_OPENSOURCE
 #endif
 
-#define QT_BUILD_KEY "macppc OpenBSD g++-3.* full-config"
+#define QT_BUILD_KEY "alpha OpenBSD g++-3.* full-config"
 
 /* Machine byte-order */
 #define Q_BIG_ENDIAN 4321
 #define Q_LITTLE_ENDIAN 1234
-#define Q_BYTE_ORDER Q_BIG_ENDIAN
+#define Q_BYTE_ORDER Q_LITTLE_ENDIAN
+/* Machine Architecture */
+#define QT_ARCH_ALPHA
 /* Compile time features */
 #define QT_LARGEFILE_SUPPORT 64
-#define QT_POINTER_SIZE 4
+#define QT_POINTER_SIZE 8
 
 #if defined(QT_BUILTIN_GIF_READER) && defined(QT_NO_BUILTIN_GIF_READER)
 # undef QT_BUILTIN_GIF_READER
@@ -39,6 +41,12 @@
 # define QT_NO_IMAGEFORMAT_MNG
 #endif
 
+#if defined(QT_NO_INOTIFY) && defined(QT_INOTIFY)
+# undef QT_NO_INOTIFY
+#elif !defined(QT_NO_INOTIFY) && !defined(QT_INOTIFY)
+# define QT_NO_INOTIFY
+#endif
+
 #if defined(QT_NO_NAS) && defined(QT_NAS)
 # undef QT_NO_NAS
 #elif !defined(QT_NO_NAS) && !defined(QT_NAS)
