@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2006 Trolltech AS. All rights reserved.
+** Copyright (C) 1992-2006 Trolltech ASA. All rights reserved.
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
@@ -26,6 +26,7 @@
 
 #include <QtCore/qbytearray.h>
 #include <QtCore/qlist.h>
+#include <QtGui/qimageiohandler.h>
 
 QT_BEGIN_HEADER
 
@@ -76,6 +77,8 @@ public:
     ImageWriterError error() const;
     QString errorString() const;
 
+    bool supportsOption(QImageIOHandler::ImageOption option) const;
+
     static QList<QByteArray> supportedImageFormats();
 
 private:
